[Zope-Checkins] CVS: ZODB3/ZEO - StorageServer.py:1.98.2.1

Jeremy Hylton jeremy@zope.com
Wed, 18 Jun 2003 13:44:45 -0400


Update of /cvs-repository/ZODB3/ZEO
In directory cvs.zope.org:/tmp/cvs-serv32649

Modified Files:
      Tag: ZODB3-3_2-branch
	StorageServer.py 
Log Message:
Make consistent use of auth_database instead of auth_filename.


=== ZODB3/ZEO/StorageServer.py 1.98 => 1.98.2.1 ===
--- ZODB3/ZEO/StorageServer.py:1.98	Fri Jun 13 15:50:05 2003
+++ ZODB3/ZEO/StorageServer.py	Wed Jun 18 13:44:44 2003
@@ -612,7 +612,7 @@
                  transaction_timeout=None,
                  monitor_address=None,
                  auth_protocol=None,
-                 auth_filename=None,
+                 auth_database=None,
                  auth_realm=None):
         """StorageServer constructor.
 
@@ -659,7 +659,7 @@
         auth_protocol -- The name of the authentication protocol to use.
             Examples are "digest" and "srp".
             
         auth_filename -- The name of the password database filename.
             It should be in a format compatible with the authentication
             protocol used; for instance, "sha" and "srp" require different
             formats.
@@ -685,7 +685,7 @@
             s._waiting = []
         self.read_only = read_only
         self.auth_protocol = auth_protocol
-        self.auth_filename = auth_filename
+        self.auth_database = auth_database
         self.auth_realm = auth_realm
         self.database = None
         if auth_protocol:
@@ -739,7 +739,7 @@
         # storages, avoiding the need to bloat each with a new authenticator
         # Database that would contain the same info, and also avoiding any
         # possibly synchronization issues between them.
-        self.database = db_class(self.auth_filename)
+        self.database = db_class(self.auth_database)
         if self.database.realm != self.auth_realm:
             raise ValueError("password database realm %r "
                              "does not match storage realm %r"
@@ -659,7 +659,7 @@
             Examples are "digest" and "srp".
             
-        auth_filename -- The name of the password database filename.
+        auth_database -- The name of the password database filename.
             It should be in a format compatible with the authentication
             protocol used; for instance, "sha" and "srp" require different